@@ -1,30 +1,22 @@
 #!/usr/bin/env python
 from __future__ import print_function
 
-import click
+import json
 import logging
 import os
-import json
-import sys
 import re
+import sys
 import threading
 
+import click
 import prompter
 import yaml
 
-from ocdeployer.utils import (
-    all_sets,
-    oc,
-    get_dir,
-    get_routes,
-    switch_to_project,
-    get_server_info,
-)
-from ocdeployer.secrets import SecretImporter
 from ocdeployer.deploy import DeployRunner
 from ocdeployer.env import EnvConfigHandler, LegacyEnvConfigHandler
 from ocdeployer.events import start_event_watcher
-
+from ocdeployer.secrets import SecretImporter
+from ocdeployer.utils import all_sets, get_dir, get_routes, get_server_info, oc, switch_to_project
 
 log = logging.getLogger("ocdeployer")
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
@@ -103,6 +95,7 @@ def verify_label(label):
     " ('oc') installed and to login to your openshift cluster before running the tool.",
     context_settings=CONTEXT_SETTINGS,
 )
+@click.version_option()
 def main():
     """Main ocdeployer group"""
     threading.current_thread().name = "main"
@@ -315,10 +308,14 @@ def deploy_dry_run(
 @common_options
 @click.option("--no-confirm", "-f", is_flag=True, help="Do not prompt for confirmation")
 @click.option(
-    "--secrets-local-dir", default=None, help="Import secrets from local files in a directory",
+    "--secrets-local-dir",
+    default=None,
+    help="Import secrets from local files in a directory",
 )
 @click.option(
-    "--secrets-src-project", default=None, help="Openshift project to import secrets from",
+    "--secrets-src-project",
+    default=None,
+    help="Openshift project to import secrets from",
 )
 @click.option(
     "--ignore-requires",
